/**
 * Copyright (c) 2008 Washington University
 */
package org.nrg.xnat.filestore;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;

import org.apache.commons.lang.StringEscapeUtils;
import org.nrg.xnat.tags.TagLabel;
import org.nrg.xnat.tags.TagLabelException;


/**
 * @author Kevin A. Archie <karchie@npg.wustl.edu>
 *
 */
public class MetadataAssignOp implements MetadataOp {
    private static final String SQL_DEFINE_METADATA = "INSERT INTO resource_tags VALUES ( ?, ?, ? )";

    private final Connection c;
    private final int tagID;
    private final Collection<String> values;

    public MetadataAssignOp(final Connection c, final int tagID, final String...values) {
	this.c = c;
	this.tagID = tagID;
	this.values = new ArrayList<String>(Arrays.asList(values));
    }

    public MetadataAssignOp(final Connection c, final TagLabel label, final String...values)
    throws SQLException,TagLabelException {
	this(c, MetadataOp.Util.getLabelID(c, label), values);
    }

    public MetadataAssignOp(final Connection c, final String label, final String...values)
    throws SQLException,TagLabelException {
    	this(c, MetadataOp.Util.getLabelID(c, label), values);
    }

    
    /* (non-Javadoc)
     * @see org.nrg.xnat.filestore.MetadataOp#apply(java.net.URI)
     */
    public void apply(final int resourceID) throws SQLException {
	final PreparedStatement assign = c.prepareStatement(SQL_DEFINE_METADATA);
	try {
	    for (final String value : values) {
		assign.setInt(1, resourceID);
		assign.setInt(2, tagID);
		assign.setString(3, StringEscapeUtils.escapeSql(value));
		try {
		    assign.executeUpdate();
		} catch (SQLException harmless) {}	// probably a duplicate value
	    }
	} finally {
	    try { assign.close(); } catch (SQLException ignore) {}
	}
    }
    
    @Deprecated	// TODO: interim
    public void close() throws SQLException { c.close(); }
}
