/**
 * Copyright (c) 2008 Washington University
 */
package org.nrg.xnat.util;

import java.util.Map.Entry;


/**
 * Immutable Map.Entry implementation
 * @author Kevin A. Archie <karchie@npg.wustl.edu>
 *
 */
public class FinalMapEntry<K,V> implements Entry<K,V> {
    private final K k;
    private final V v;
    
    public FinalMapEntry(final K key, final V value) {
	if (null == key) {
	    throw new IllegalArgumentException("key value must be non-null");
	}
	this.k = key;
	this.v = value;
    }
    
    public final boolean equals(final Object o) {
	if (this.getClass().equals(o.getClass())) {
	    final FinalMapEntry<?,?> other = (FinalMapEntry<?,?>)o;
	    return k.equals(other.k)
	    	&& null == v ? null == other.v : v.equals(other.v);
	} else {
	    return false;
	}
    }
    
    public K getKey() { return k; }

    public V getValue() { return v; }

    public int hashCode() { return k.hashCode(); }

    public V setValue(final V v) { throw new UnsupportedOperationException(); }
}
